@@ -469,5 +469,13 @@ anovaOneWClass <- if (requireNamespace('jmvcore')) R6::R6Class(
             dat <- as.data.frame(lapply(dat, unlist))
 
             return(dat)
+        },
+        .sourcifyOption = function(option) {
+            if (option$name %in% c('deps', 'group'))
+                return('')
+            super$.sourcifyOption(option)
+        },
+        .formula = function() {
+            jmvcore:::composeFormula(self$options$deps, self$options$group)
         })
 )
