@@ -18,6 +18,7 @@ anovaRMClass <- R6::R6Class(
             private$.initPostHocTables()
             private$.initEmm()
             private$.initEmmTable()
+            private$.initGroupSummary()
 
             measures <- lapply(self$options$rmCells, function(x) x$measure)
             areNull  <- vapply(measures, is.null, FALSE, USE.NAMES=FALSE)
@@ -56,6 +57,7 @@ anovaRMClass <- R6::R6Class(
 
                 private$.prepareEmmPlots(result, data)
                 private$.populateEmmTables()
+                private$.populateGroupSummaryTable()
             }
         },
 
@@ -70,15 +72,15 @@ anovaRMClass <- R6::R6Class(
 
             if (length(rmTerms) > 0) {
                 for (i in seq_along(rmTerms)) {
-                    name <- stringifyTerm(rmTerms[i])
+                    name <- stringifyTerm(rmTerms[[i]])
                     values <- list(
                         `name[none]`=name,
                         `name[GG]`=name,
                         `name[HF]`=name)
                     if (rmTerms[i] == 'Residual')
-                        key <- unlist(c(rmTerms[i-1],'.RES'))
+                        key <- unlist(c(rmTerms[[i-1]],'.RES'))
                     else
-                        key <- unlist(rmTerms[i])
+                        key <- unlist(rmTerms[[i]])
                     rmTable$addRow(rowKey=key, values)
                 }
             } else {
@@ -276,6 +278,41 @@ anovaRMClass <- R6::R6Class(
             }
         },
 
+        .initGroupSummary = function() {
+
+            table <- self$results$groupSummary
+            bs <- self$options$bs
+
+            bs <- lapply(bs, function(x) self$data[[x]])
+            levels <- lapply(bs, levels)
+            groups <- expand.grid(levels)
+            if (nrow(groups) == 0) {
+                groups <- data.frame(x='')
+                colnames(groups) <- ''
+            } else {
+                colnames(groups) = self$options$bs
+            }
+
+            titles = colnames(groups)
+            names = paste0('group:', titles)
+
+            for (i in seq_len(ncol(groups))) {
+                table$addColumn(
+                    index=1,
+                    name=names[i],
+                    title=titles[i],
+                    type='text',
+                    combineBelow=TRUE
+                )
+            }
+
+            for (i in seq_len(nrow(groups))) {
+                values <- apply(groups[i,,drop=FALSE], 2, paste)
+                names(values) <- names
+                table$addRow(rowKey=unname(values), values=values)
+            }
+        },
+
         #### Populate tables functions ----
         .populateEffectsTables=function(result) {
 
@@ -287,11 +324,13 @@ anovaRMClass <- R6::R6Class(
             })
             model <- summaryResult$univariate.tests
             epsilon <- summaryResult$pval.adjustments
+            ges <- result$anova_table
 
             rmRows <- rmTable$rowKeys
             bsRows <- bsTable$rowKeys
             modelRows <- jmvcore::decomposeTerms(as.list(rownames(model)))
             epsilonRows <- jmvcore::decomposeTerms(as.list(rownames(epsilon)))
+            gesRows <- jmvcore::decomposeTerms(as.list(rownames(ges)))
 
             SSt <- private$.getSSt(model)
 
@@ -332,10 +371,15 @@ anovaRMClass <- R6::R6Class(
                     dfResHF <- dfRes * HF
                     row[['p[HF]']] <- pf(row[['F[HF]']], row[['df[HF]']], dfResHF, lower.tail=FALSE)
 
+                    gesIndex <- which(sapply(gesRows, function(x) setequal(toB64(rmRows[[i]]), x)))
+                    gesValue <- ges[gesIndex, 'ges']
+
                     # Add effect sizes
                     SSr <- model[index,'Error SS']
                     MSr <- SSr/dfRes
+
                     row[['eta[none]']] <- row[['eta[GG]']] <- row[['eta[HF]']] <- row[['ss[none]']] / SSt
+                    row[['ges[none]']] <- row[['ges[GG]']] <- row[['ges[HF]']] <- gesValue
                     row[['partEta[none]']] <- row[['partEta[GG]']] <- row[['partEta[HF]']] <- row[['ss[none]']] / (row[['ss[none]']] + SSr)
 
                     omega <- (row[['ss[none]']] - (row[['df[none]']] * MSr)) / (SSt + MSr)
@@ -355,6 +399,7 @@ anovaRMClass <- R6::R6Class(
                     row[['ms[none]']] <- row[['ss[none]']] / row[['df[none]']]
                     row[['F[none]']] <- row[['F[GG]']]  <- row[['F[HF]']] <- ''
                     row[['p[none]']] <- row[['p[GG]']] <- row[['p[HF]']] <- ''
+                    row[['ges[none]']] <- row[['ges[GG]']] <- row[['ges[HF]']] <- ''
                     row[['eta[none]']] <- row[['eta[GG]']] <- row[['eta[HF]']] <- ''
                     row[['partEta[none]']] <- row[['partEta[GG]']] <- row[['partEta[HF]']] <- ''
                     row[['omega[none]']] <- row[['omega[GG]']] <- row[['omega[HF]']] <- ''
@@ -392,6 +437,7 @@ anovaRMClass <- R6::R6Class(
                 if (! bsRows[[i]][1] == 'Residual') { # if the row is not a residual
 
                     index <- which(sapply(modelRows, function(x) setequal(toB64(bsRows[[i]]), x)))
+                    gesIndex <- which(sapply(gesRows, function(x) setequal(toB64(bsRows[[i]]), x)))
 
                     row <- list()
                     row[['ss']] <- model[index,'Sum Sq']
@@ -403,6 +449,7 @@ anovaRMClass <- R6::R6Class(
                     # Add effect sizes
                     SSr <- model[index,'Error SS']
                     MSr <- SSr/model[index,'den Df']
+                    row[['ges']] <- ges[gesIndex, 'ges']
                     row[['eta']] <- row[['ss']] / SSt
                     row[['partEta']] <- row[['ss']] / (row[['ss']] + SSr)
                     omega <- (row[['ss']] - (row[['df']] * MSr)) / (SSt + MSr)
@@ -416,7 +463,7 @@ anovaRMClass <- R6::R6Class(
                     row[['ss']] <- model['(Intercept)','Error SS']
                     row[['df']] <- model['(Intercept)','den Df']
                     row[['ms']] <- row[['ss']] / row[['df']]
-                    row[['F']] <- row[['p']] <- row[['eta']] <- row[['partEta']] <- row[['omega']] <-''
+                    row[['F']] <- row[['p']] <- row[['ges']] <- row[['eta']] <- row[['partEta']] <- row[['omega']] <-''
 
                     bsTable$setRow(rowNo=i, values=row)
                 }
@@ -623,6 +670,28 @@ anovaRMClass <- R6::R6Class(
             }
         },
 
+        .populateGroupSummaryTable = function() {
+
+            table <- self$results$groupSummary
+            data <- self$data
+            bs <- self$options$bs
+            complete <- complete.cases(data)
+
+            if (length(bs) == 0) {
+                n <- sum(complete)
+                ex <- length(complete) - n
+                table$setRow(rowNo=1, values=list(n=n, ex=ex))
+            } else {
+                by <- lapply(bs, function(x) self$data[[x]])
+                rm <- lapply(self$options$rmCells, function(x) x$measure)
+                nt <- aggregate(complete, by=by, length)$x
+                n <- aggregate(complete, by=by, sum)$x
+                ex <- nt - n
+                for (i in seq_along(n))
+                    table$setRow(rowNo=i, values=list(n=n[i], ex=ex[i]))
+            }
+        },
+
         #### Plot functions ----
         .prepareEmmPlots = function(model, data) {
 
